<?xml version="1.0"?>

<!--
  Copyright (c) 1997-2009
  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Darmstadt, Germany)
  http://www.polymake.de

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version: http://www.gnu.org/licenses/gpl.txt.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
===============================================================================
  $Project: polymake $$Id: upgrade-2.9.12.xslt 11296 2013-07-29 23:51:25Z gawrilow $

  In all objects of type PolyhedralFan or derived thereof:
    Decrease COMBINATORIAL_DIM by 1.
    Replace MAXIMAL_CONES_DIMS with MAXIMAL_CONES_COMBINATORIAL_DIMS and amend if necessary.
-->

<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
			     xmlns:p="http://www.math.tu-berlin.de/polymake/#3">

<xsl:output method="xml" encoding="utf-8" cdata-section-elements="description" indent="yes" />

<!-- detect the PolyhedralFan objects -->
<xsl:template match="/p:object[@type[contains(string(),'PolyhedralFan')]]">
  <xsl:element name="{name()}" namespace="{namespace-uri()}">
    <xsl:copy-of select="@*[name()!='tm' and name()!='version']" />
    <xsl:apply-templates select="./node()" mode="fan" />
  </xsl:element>
</xsl:template>

<!-- decrease COMBINATORIAL_DIM -->
<xsl:template match="p:property[@name='COMBINATORIAL_DIM']" mode="fan">
<xsl:variable name="comdim" select="@value" /> 
  <xsl:element name="property" namespace="{namespace-uri()}">
    <xsl:attribute name="name">COMBINATORIAL_DIM</xsl:attribute>
    <xsl:attribute name="value">
      <xsl:value-of select="$comdim - 1" />
    </xsl:attribute>
  </xsl:element>
</xsl:template>

<!-- transform MAXIMAL_CONES_COMBINATORIAL_DIMS -->
<xsl:template match="p:property[@name='MAXIMAL_CONES_DIMS']" mode="fan">
<xsl:variable name="max_cones_dims" select="./p:v/text()" />
<xsl:choose>
    <xsl:when test="../p:property[@name='LINEALITY_DIM']">
      <xsl:variable name="lin_dim" select="../p:property[@name='LINEALITY_DIM']/@value" />
      <xsl:element name="property" namespace="{namespace-uri()}">
        <xsl:attribute name="name">MAXIMAL_CONES_COMBINATORIAL_DIMS</xsl:attribute>
       <xsl:element name="v" namespace="{namespace-uri()}">
          <xsl:call-template name="sub_constant">
	        <xsl:with-param name="values" select="$max_cones_dims"/>
                <xsl:with-param name="constant" select="$lin_dim + 1"/>
          </xsl:call-template>
           </xsl:element>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:element name="property" namespace="{namespace-uri()}">
        <xsl:attribute name="name">MAXIMAL_CONES_COMBINATORIAL_DIM</xsl:attribute>         
        <xsl:element name="v" namespace="{namespace-uri()}">
          <xsl:call-template name="sub_constant">
	        <xsl:with-param name="values" select="$max_cones_dims"/>
                <xsl:with-param name="constant" select="1"/>
            </xsl:call-template>
        </xsl:element>
      </xsl:element>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- utility function substracting values from an array represented as a string of nubmers -->
<xsl:template name="sub_constant">
        <xsl:param name="values"/>
	<xsl:param name="constant"/>
	<xsl:variable name="n_values" select="normalize-space($values)"/>
	<xsl:variable name="first" select="substring-before($n_values,' ')" />
        <xsl:variable name="remaining" select="substring-after($n_values, ' ')" />
   	<xsl:if test="$first!=''">
            <xsl:value-of select="$first - $constant" />
            <xsl:text> </xsl:text>
	 </xsl:if>
        <xsl:choose>
          <xsl:when test="$remaining!=''">
            <xsl:call-template name="sub_constant">
	      <xsl:with-param name="values" select="$remaining"/>
              <xsl:with-param name="constant" select="$constant"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$n_values - $constant" />
          </xsl:otherwise>
        </xsl:choose> 
</xsl:template>



<!-- everything else is copied verbatim by switching back to the default mode -->

<xsl:template match="*" mode="fan">
  <xsl:apply-templates select="." />
</xsl:template>

<xsl:include href="trivial-copy.xslt" />

</xsl:transform>
