<?xml version="1.0"?>

<!--
  Copyright (c) 1997-2011
  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Darmstadt, Germany)
  http://www.polymake.de

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version: http://www.gnu.org/licenses/gpl.txt.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
===============================================================================
  $Project: polymake $$Id: upgrade-2.9.14.xslt 10156 2011-04-14 09:15:38Z sherrmann $

  In all objects of type PolyhedralFan or derived thereof:
    Replace DIM with FAN_DIM and AMBIENT_DIM with FAN_AMBIENT_DIM.
-->

<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
			     xmlns:p="http://www.math.tu-berlin.de/polymake/#3">

<xsl:output method="xml" encoding="utf-8" cdata-section-elements="description" indent="yes" />

<!-- detect the PolyhedralFan objects -->
<xsl:template match="/p:object[@type[contains(string(),'Fan')]]">
  <xsl:element name="{name()}" namespace="{namespace-uri()}">
    <xsl:copy-of select="@*[name()!='tm' and name()!='version']" />
    <xsl:apply-templates select="./node()" mode="fan" />
  </xsl:element>
</xsl:template>

<!-- change AMBIENT_DIM to FAN_AMBIENT_DIM-->
<xsl:template match="p:property[@name='AMBIENT_DIM']" mode="fan">
<xsl:variable name="dim" select="@value" /> 
  <xsl:element name="property" namespace="{namespace-uri()}">
    <xsl:attribute name="name">FAN_AMBIENT_DIM</xsl:attribute>
    <xsl:attribute name="value">
      <xsl:value-of select="$dim" />
    </xsl:attribute>
  </xsl:element>
</xsl:template>

<!-- change DIM to FAN_DIM-->
<xsl:template match="p:property[@name='DIM']" mode="fan">
<xsl:variable name="dim" select="@value" /> 
  <xsl:element name="property" namespace="{namespace-uri()}">
    <xsl:attribute name="name">FAN_DIM</xsl:attribute>
    <xsl:attribute name="value">
      <xsl:value-of select="$dim" />
    </xsl:attribute>
  </xsl:element>
</xsl:template>

<!-- everything else is copied verbatim by switching back to the default mode -->

<xsl:template match="*" mode="fan">
  <xsl:apply-templates select="." />
</xsl:template>


<!-- detect the SimplicialComplex objects -->
<xsl:template match="/p:object[@type[contains(string(),'SimplicialComplex')]]">
  <xsl:element name="{name()}" namespace="{namespace-uri()}">
    <xsl:copy-of select="@*[name()!='tm' and name()!='version']" />
    <xsl:apply-templates select="./node()" mode="simplicial_complex" />
  </xsl:element>
</xsl:template>

<!-- change BALANCED to FOLDABLE -->
<xsl:template match="p:property[@name='BALANCED']" mode="simplicial_complex">
<xsl:variable name="truefalse" select="@value" /> 
  <xsl:element name="property" namespace="{namespace-uri()}">
    <xsl:attribute name="name">FOLDABLE</xsl:attribute>
    <xsl:attribute name="value">
      <xsl:value-of select="$truefalse" />
    </xsl:attribute>
  </xsl:element>
</xsl:template>

<!-- everything else is copied verbatim by switching back to the default mode -->

<xsl:template match="*" mode="simplicial_complex">
  <xsl:apply-templates select="." />
</xsl:template>


<xsl:include href="trivial-copy.xslt" />

</xsl:transform>
